@@ -1,47 +1,10 @@
 from ipaddress import ip_network, ip_address
 from pulumi import ComponentResource, ResourceOptions, StackReference
-from ..resources import route_table, vnet, firewall, vpn_gateway, bastion_hosts
-
-
-
-class HubProps:
-    def __init__(
-            self,
-            azure_bastion: bool,
-            forced_tunnel: bool,
-            firewall_address_space: str,
-            hub_address_space: str,
-            location: str,
-            peer: str,
-            reference: StackReference,
-            resource_group_name: str,
-            separator: str,
-            stack: str,
-            subnets: [str, str, str],
-            suffix: str,
-            preffix: str,
-            proj: str,
-            tags: [str, str],
-    ):
-        self.azure_bastion = azure_bastion
-        self.forced_tunnel = forced_tunnel
-        self.firewall_address_space = firewall_address_space
-        self.hub_address_space = hub_address_space
-        self.location = location
-        self.peer = peer
-        self.reference = reference
-        self.resource_group_name = resource_group_name
-        self.separator = separator
-        self.stack = stack
-        self.subnets = subnets
-        self.suffix = suffix
-        self.preffix = preffix
-        self.proj = proj
-        self.tags = tags
+from resources import route_table, vnet, firewall, vpn_gateway, bastion_hosts
 
 
 class Hub(ComponentResource):
-    def __init__(self, name: str, props: HubProps, opts: ResourceOptions = None):
+    def __init__(self, name: str, props: None, opts: ResourceOptions = None):
         super().__init__('vdc:network:Hub', name, {}, opts)
 
         hubResources = [route_table, vnet, firewall, vpn_gateway, bastion_hosts]
@@ -49,13 +12,8 @@ class Hub(ComponentResource):
         for resource in hubResources:
             resource.location = props.location
             resource.resource_group_name = props.resource_group_name
-            resource.s = props.separator
             resource.self = self
-            resource.suffix = props.suffix
-            resource.preffix = props.preffix
-            resource.proj = props.proj
             resource.tags = props.tags
-            resource.stack = props.stack
 
             
         # # calculate the subnets in the firewall_address_space
@@ -91,26 +49,28 @@ class Hub(ComponentResource):
 
         # Azure Virtual Network to which spokes will be peered
         # separate address spaces to simplify custom routing
-        hub = vnet.virtual_network(name, [
-            #props.firewall_address_space,
-            props.hub_address_space,
-        ],)
+        hub = vnet.virtual_network(
+            f'Hub', 
+            [
+                #props.firewall_address_space,
+                props.hub_address_space,
+            ],)
 
         # AzureFirewallManagementSubnet and Route Table
         # https://docs.microsoft.com/en-us/azure/firewall/forced-tunneling
         hub_fwm_rt = route_table.route_table(
-            stem=f'{name}{s}fwm',
+            stem=f'firewall-mgmt',
             disable_bgp_route_propagation=True,  # required
         )
 
         # only a default route to the Internet is permitted
         hub_fwm_dg = route_table.route_to_internet(
-            stem=f'fwm{s}internet',
+            stem=f'firewall_mgmt-internet',
             route_table_name=hub_fwm_rt.name,
         )
 
         hub_fwm_sn = vnet.subnet_special(
-            stem=f'{name}{s}fwm',
+            stem=f'firewall-mgmt',
             name='AzureFirewallManagementSubnet',  # name required
             virtual_network_name=hub.name,
             address_prefix='172.16.1.0/24',
@@ -120,7 +80,7 @@ class Hub(ComponentResource):
 
         # AzureFirewallSubnet Route Table 
         hub_fw_rt = route_table.route_table(
-            stem=f'{name}{s}fw',
+            stem=f'firewall',
             disable_bgp_route_propagation=False,
         )
 
@@ -130,12 +90,12 @@ class Hub(ComponentResource):
         private_ranges = 'IANAPrivateRanges'
         if not props.forced_tunnel:
             hub_fw_dg = route_table.route_to_internet(
-                stem=f'fw{s}internet',
+                stem=f'firewall-internet',
                 route_table_name=hub_fw_rt.name,
             )
         else:
             hub_fw_dg = route_table.route_to_virtual_appliance(
-                stem=f'fw{s}tunnel',
+                stem=f'firewall-tunnel',
                 route_table_name=hub_fw_rt.name,
                 address_prefix='0.0.0.0/0',
                 next_hop_ip_address=props.forced_tunnel,
@@ -146,7 +106,7 @@ class Hub(ComponentResource):
 
         
         hub_fw_sn = vnet.subnet_special(
-            stem=f'{name}{s}fw',
+            stem=f'firewall',
             name='AzureFirewallSubnet',  # name required
             virtual_network_name=hub.name,
             address_prefix='172.16.2.0/24',
@@ -156,7 +116,7 @@ class Hub(ComponentResource):
 
         # Azure Firewall
         hub_fw = firewall.firewall(
-            stem=name,
+            stem=f'Hub',
             fw_sn_id=hub_fw_sn.id,
             fwm_sn_id=hub_fwm_sn.id,
             private_ranges=private_ranges,
@@ -174,21 +134,21 @@ class Hub(ComponentResource):
 
         # GatewaySubnet and Route Table
         hub_gw_rt = route_table.route_table(
-            stem=f'{name}{s}gw',
+            stem=f'Hub',
             disable_bgp_route_propagation=False,
             depends_on=None,
         )
 
         # protect intra-GatewaySubnet traffic from being redirected:
         hub_gw_gw = route_table.route_to_virtual_network(
-            stem=f'gw{s}gw',
+            stem=f'Hub',
             route_table_name=hub_gw_rt.name,
             address_prefix=gws_ar,
         )
 
         # redirect traffic from gateways to hub via firewall
         hub_gw_hub = route_table.route_to_virtual_appliance(
-            stem=f'gw{s}hub',
+            stem=f'Hub',
             route_table_name=hub_gw_rt.name,
             address_prefix=props.hub_address_space,
             next_hop_ip_address=hub_fw_ip,
@@ -196,7 +156,7 @@ class Hub(ComponentResource):
 
         # Create gateway Subnet
         hub_gw_sn = vnet.subnet_special(
-            stem=f'{name}{s}gw',
+            stem=f'gateway',
             name='GatewaySubnet',  # name required
             virtual_network_name=hub.name,
             address_prefix='172.16.3.0/24',
@@ -206,21 +166,21 @@ class Hub(ComponentResource):
 
         # Create VPN Gateway
         hub_vpn_gw = vpn_gateway.vpn_gateway(
-            stem=name,
+            stem='Hub',
             subnet_id=hub_gw_sn.id,
             depends_on=[hub_gw_sn],
         )
 
          # Route Table to be associated with all hub shared services subnets
         hub_ss_rt = route_table.route_table(
-            stem=f'{name}{s}ss',
+            stem=f'shared-services',
             disable_bgp_route_propagation=True,
             depends_on=[hub_vpn_gw],
         )
 
         # default route from hub via the firewall
         hub_ss_dg = route_table.route_to_virtual_appliance(
-            stem=f'ss{s}dg',
+            stem=f'shared-srv-inet',
             route_table_name=hub_ss_rt.name,
             address_prefix='0.0.0.0/0',
             next_hop_ip_address=hub_fw_ip,
@@ -228,7 +188,7 @@ class Hub(ComponentResource):
 
         # redirect traffic from hub to gateways via the firewall
         hub_ss_gw = route_table.route_to_virtual_appliance(
-            stem=f'ss{s}gw',
+            stem=f'shared-srv-gw',
             route_table_name=hub_ss_rt.name,
             address_prefix=gws_ar,
             next_hop_ip_address=hub_fw_ip,
@@ -248,7 +208,7 @@ class Hub(ComponentResource):
         # Azure Bastion subnet and host (optional)
         if props.azure_bastion:
             hub_ab = bastion_hosts.bastion_host(
-                stem=name,
+                stem='Hub',
                 virtual_network_name=hub.name,
                 address_prefix='172.16.4.0/24',
                 depends_on=[hub_vpn_gw],
